==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/outputs/WorkflowStepDecryptStepDetailsDestinationFileLocation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property efsFileLocation Specifies the details for the EFS file being copied.
 * @property s3FileLocation Specifies the details for the S3 file being copied.
 */
public data class WorkflowStepDecryptStepDetailsDestinationFileLocation(
    public val efsFileLocation: WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocation? =
        null,
    public val s3FileLocation: WorkflowStepDecryptStepDetailsDestinationFileLocationS3FileLocation? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.transfer.outputs.WorkflowStepDecryptStepDetailsDestinationFileLocation):
            WorkflowStepDecryptStepDetailsDestinationFileLocation =
            WorkflowStepDecryptStepDetailsDestinationFileLocation(
                efsFileLocation = javaType.efsFileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                s3FileLocation = javaType.s3FileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowStepDecryptStepDetailsDestinationFileLocationS3FileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/outputs/WorkflowStepDecryptStepDetailsDestinationFileLocation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property efsFileLocation Specifies the details for the EFS file being copied.
 * @property s3FileLocation Specifies the details for the S3 file being copied.
 */
public data class WorkflowStepDecryptStepDetailsDestinationFileLocation(
    public val efsFileLocation: WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocation? =
        null,
    public val s3FileLocation: WorkflowStepDecryptStepDetailsDestinationFileLocationS3FileLocation? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.transfer.outputs.WorkflowStepDecryptStepDetailsDestinationFileLocation): WorkflowStepDecryptStepDetailsDestinationFileLocation =
            WorkflowStepDecryptStepDetailsDestinationFileLocation(
                efsFileLocation = javaType.efsFileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                s3FileLocation = javaType.s3FileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowStepDecryptStepDetailsDestinationFileLocationS3FileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
